@@ -3,15 +3,19 @@
 # Copy-right 2007 - current Tina4
 # License: MIT https://opensource.org/licenses/MIT
 #
-
-DEBUG_INFO = 0
-DEBUG_WARNING = 1
-DEBUG_DEBUG = 2
+# flake8: noqa: E501
+TINA4_LOG_INFO = "INFO"
+TINA4_LOG_WARNING = "WARN"
+TINA4_LOG_DEBUG = "DEBUG"
+TINA4_LOG_ERROR = "ERROR"
+TINA4_LOG_ALL = "ALL"
 
 TINA4_GET = "GET"
 TINA4_POST = "POST"
 TINA4_ANY = "ANY"
 TINA4_PATCH = "PATCH"
+TINA4_PUT = "PUT"
+TINA4_DELETE = "DELETE"
 TINA4_OPTIONS = "OPTIONS"
 
 HTTP_OK = 200
@@ -22,16 +26,15 @@ HTTP_BAD_REQUEST = 400
 HTTP_UNAUTHORIZED = 401
 HTTP_FORBIDDEN = 403
 HTTP_NOT_FOUND = 404
+HTTP_REDIRECT = 302
 
 LOOKUP_HTTP_CODE = {HTTP_OK: "OK", HTTP_CREATED: "Created", HTTP_BAD_REQUEST: "Bad Request",
                     HTTP_PARTIAL_CONTENT: "Partial Content", HTTP_UNAUTHORIZED: "Unauthorized",
-                    HTTP_FORBIDDEN: "Forbidden", HTTP_NOT_FOUND: "Not Found", HTTP_NO_CONTENT: "No Content"}
+                    HTTP_FORBIDDEN: "Forbidden", HTTP_NOT_FOUND: "Not Found", HTTP_NO_CONTENT: "No Content",
+                    HTTP_REDIRECT: "Redirect"}
 
 TEXT_HTML = "text/html"
+TEXT_CSS = "text/css"
 TEXT_PLAIN = "text/plain"
 APPLICATION_JSON = "application/json"
 APPLICATION_XML = "application/xml"
-
-
-
-
